@@ -3,7 +3,7 @@
  *
  * 11/03/95, Kay Roemer.
  *
- * 9705, John Blakeley.
+ * 9705,9802 John Blakeley.
  */
 
 #ifndef _AUDIOS_H
@@ -23,21 +23,17 @@
 #define AIOCSYNC	(('A' << 8) | 6)	/* wait until playing done */
 #define AIOCGBLKSIZE	(('A' << 8) | 7)	/* get dma block size */
 
-#define AIOCSSPEED	(('A' << 8) | 8)	/* set play speed */
-#define AIOCGSPEED	(('A' << 8) | 9)	/* get play speed */
-#define AIOCSSTEREO	(('A' << 8) | 10)	/* stereo on/off */
-#define AIOCGCHAN	(('A' << 8) | 11)	/* get # of channels */
+#define AIOCSSPEED	(('A' << 8) | 8)	/* set play or record speed */
+#define AIOCGSPEED	(('A' << 8) | 9)	/* get play or record speed */
+#define AIOCGCHAN	(('A' << 8) | 10)	/* get # of channels */
+#define AIOCSCHAN	(('A' << 8) | 11)	/* set # of channels */
 
 #define AIOCGFMTS	(('A' << 8) | 12)	/* get supp. sample formats */
 #define AIOCSFMT	(('A' << 8) | 13)	/* set sample format */
 #define AFMT_U8		0x00000001L		/* 8 bits, unsigned */
 #define AFMT_S8		0x00000002L		/* 8 bits, signed */
 #define AFMT_ULAW	0x00000004L		/* u law encoding */
-#define AFMT_ALAW	0x00000008L		/* a law encoding */
-#define AFMT_U16	0x00000010L		/* 16 bits, unsigned */
-#define	AFMT_S16	0x00000020L		/* 16 bits, signed */
-
-#define AIOCSCHAN	(('A' << 8) | 14)	/* start record */
-#define AIOCSREC	(('A' << 8) | 15)	/* record on/off */
+#define AFMT_U16	0x00000008L		/* 16 bits, unsigned */
+#define AFMT_S16	0x00000010L		/* 16 bits, signed */
 
 #endif
