@@ -2,51 +2,54 @@
  * interface to sound hardware drivers for /dev/audio.
  *
  * 11/03/95, Kay Roemer.
+ *
+ * 9802, John Blakeley - supporting F030's recording ability.
  */
 
 #ifndef _DEVICE_H
 #define _DEVICE_H
 
 /*
- * sound hardware descriptor
- */
-struct device {
-	short	channels;
-	void	(*reset) (void);
-	long	(*copyin) (char *buf, long len);
-	long	(*ioctl) (short mode, void *arg);
-	long	(*wspace) (void);
-	long	(*mix_ioctl) (short cmd, void *arg);
-};
-
-/*
- * play buffer
+ * sample buffer - 2 * 32K
  */
 #define BUFSIZE (0x8000L - sizeof (long))
 
+/*
+ * sound hardware descriptor
+ */
+struct device {
+	short	maxchans;		/* max. no. of channels supported */
+	short	curchans;		/* 1 = mono, 2 = stereo, 4 = quad, etc */
+	short	format_map;		/* bitmask of AFMT_???? */
+	short	curformat;
+	short	ssize;	/* 8 = 8bits, 16 = 16bits */
+	short	status;			/* rec < 0 < playing */
+	long	srate;
+	void	(*reset) (void);
+	void	*(*copyfn) (void *dst, const void *src, size_t len);
+	long	(*copyin) (char *buf, long len);
+	long	(*copyout) (char *buf, long len);
+	long	(*ioctl) (short mode, void *arg);
+	long	(*wspace) (void);
+	long	(*rspace) (void);
+	long	(*mix_ioctl) (short cmd, void *arg);
+};
+
+extern struct device thedev;
+
 struct dmabuf {
-	unsigned char buf[BUFSIZE];
 	long used;
+	unsigned char buf[BUFSIZE];
 };
 
 extern struct dmabuf dmab[2];
 
 /*
- * 0 (not currently playing), >=1 (playing)
- */
-extern volatile short playing;
-
-/*
- * index into dmab. points to buffer currenly beeing filled
+ * index into dmab. points to buffer currently being filled
  * by write().
  */
 extern volatile short bufidx;
 
-/*
- * sample format converter
- */
-extern void *(*copyfn) (void *dst, const void *src, size_t len);
-
 /*
  * write selector.
  */
